import { reportError } from '@/events';
import { hostEmitter } from '@jolibox/common';
import { HostEventParamsMap } from '@jolibox/types';
import { APIError } from '@jolibox/common';

// Define the custom events we want to support
type CustomEventType = 'onI18nChanged' | 'onBackPress';

const supportedEvents = ['onI18nChanged', 'onBackPress'];

export const onCustomEvent = <T extends CustomEventType>(event: T, callback: HostEventParamsMap[T]) => {
  if (!supportedEvents.includes(event)) {
    reportError(new APIError(`[onCustomEvent] Unsupported event: ${event}`, 2000));
  }

  hostEmitter.on(event, callback);
};

export const offCustomEvent = <T extends CustomEventType>(event: T, callback: HostEventParamsMap[T]) => {
  if (!supportedEvents.includes(event)) {
    reportError(new APIError(`[offCustomEvent] Unsupported event: ${event}`, 2000));
  }

  hostEmitter.off(event, callback);
};

export const onceCustomEvent = <T extends CustomEventType>(event: T, callback: HostEventParamsMap[T]) => {
  if (!supportedEvents.includes(event)) {
    reportError(new APIError(`[onceCustomEvent] Unsupported event: ${event}`, 2000));
  }

  hostEmitter.once(event, callback);
};
